/*
 * Copyright 2016 - 2021 gary@drinkingtea.net
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

#include <ox/std/defines.hpp>

#if !defined(OX_OS_Windows) && !defined(OX_OS_Darwin)
#include <gtk/gtk.h>

#include <ox/std/defer.hpp>
#include <ox/std/string.hpp>

namespace nostalgia::studio {

ox::Result<ox::String> chooseDirectory() noexcept {
	ox::Result<ox::String> out;
	const auto action = GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER;
	gtk_init(nullptr, nullptr);
	auto dialog = gtk_file_chooser_dialog_new("Open Project Directory", nullptr, action,
	                                          ("_Cancel"), GTK_RESPONSE_CANCEL,
	                                          ("_Open"), GTK_RESPONSE_ACCEPT,
	                                          nullptr);
	const auto res = gtk_dialog_run(GTK_DIALOG(dialog));
	if (res == GTK_RESPONSE_ACCEPT) {
		auto chooser = GTK_FILE_CHOOSER(dialog);
		auto path = gtk_file_chooser_get_filename(chooser);
		out = ox::String(path);
		g_free(path);
	} else {
		out = OxError(1);
	}
	gtk_widget_destroy(dialog);
	// for some reason we need to 4 iterations through the main loop to destroy the dialog
	for (int i = 0; i < 4; ++i) {
		gtk_main_iteration_do(false);
	}
	return out;
}

}
#endif